#Required packages
library(dplyr)
library(tidyr)
library(ggplot2)
library(cowplot)
library(lubridate)
library(chron)
library(fishualize)

# Set figure color scheme
pal <- fish(n = 4, option ="Scarus_quoyi", begin = 0.3, end = 0.9) 

# Plot paternal hatching

## Load Data: PaternalHatching.csv
ps.data<-read.csv("PaternalHatching.csv")
#-or-
# select file manually
#morph <- read.csv(file.choose(), header = TRUE)

## Data for plotting light and dark photo periods
photoperiod <- read.csv("photoperiod.csv")

## Generate dataframe for adding lines to figure
sunrise <- c(170, 162, 154)
Time_observed2 <- c(6, 14, 22)
sunrise <- data.frame(Time_observed=Time_observed2, sunrise)

## Figure labels
Time_labels <- c(`6` = "06:00h",
                 `14` = "14:00h",
                 `22` = "22:00h")

## Plot hatching age and duration by time observed
PS.plot <- ggplot() +
  geom_rect(data=photoperiod %>% filter(AgeHPF >= 150, AgeHPF <= 172), 
            (aes(xmin=AgeHPF,xmax=AgeHPF+1, ymin=0, ymax=9, fill=factor(Light))), alpha = 0.5)+
  scale_fill_manual(values=c("lightgrey", "white", pal, "black"), guide="none") +
  scale_color_manual(values=c(pal[[3]], "black"), guide="none") +
  geom_vline(data = sunrise, aes(xintercept = sunrise), 
             color = "black", linetype = "dashed") +
  geom_segment(data= ps.data, aes(x = Hatch_age_min, xend = Hatch_age_max, y = ID, yend = ID), 
               size = 2, color = pal[[3]]) +
  geom_point(data= ps.data, aes(x = Hatch_age_min, y = ID), 
             size=2.5, shape=21, fill = "white", color = pal[[3]]) +
  geom_point(data= ps.data, aes(x = Hatch_age_max, y = ID), 
             size=2.5, shape=21, fill = "white", color = pal[[3]]) +
  facet_grid(factor(Time_observed)~., labeller = as_labeller(Time_labels)) +
  scale_x_continuous(breaks=seq(150,172,2), 
                     expand = expansion(mult = c(0, 0))) +
  scale_y_continuous(breaks=seq(0,8,4),expand = expansion(mult = c(0, 0))) +
  xlab("Age range of paternally hatched embryos (HPF)") +
  ylab("Time of day when clutch was first observed") +
  theme_half_open(10)+
  panel_border()
PS.plot
